@@ -78,6 +78,8 @@ class DatabaseManager:
 
     def __init__(self,**kwargs):
         self._raw_sql_parse_data = None
+        self.init_gen_insert = False
+
 
         self.data = {
             "name":_csu.to_snake_case(_obj.get_kwarg(['name'],f"database_{_csu.gen.rand()}",(str),**kwargs)),
@@ -499,6 +501,7 @@ class DatabaseManager:
             master_data['test'][t.table_name] = test_data
 
         self.data['insert_data'] = master_data
+        self.init_gen_insert = True
 
         # TODO []: remove this, only for testing shit.
         _cfu.writer.to_json("dbman.insert.json",data)
@@ -840,22 +843,6 @@ class DatabaseManager:
         for tb in self.data['tables_instances']:
             tb.delete_test_data()
 
-    # def delete_table(self,table_names:_Union[list,str]):
-    #     table_names = _lu.force_list(table_names)
-    #     for table_name in table_names:
-    #         # @Mstep [] get the table instance.
-    #         tb = self.table(table_name)
-    #         # @Mstep [] delete the table from the data dictionaries.
-    #         # _remove_table_data_dict(self,tb.name)
-
-    #         # @Mstep [] delete the table's directory and data.
-    #         tb.delete()
-
-    #         # @Mstep [] remove the table instance.
-    #         _delete_table_instance(self,tb.name)
-    #     self.save_master_summary()
-
-
     def purge_tables(self):
         '''
             Delete table directories that do not correspond the the master sql.
@@ -1320,7 +1307,7 @@ class DatabaseManager:
             `method_insert_data`: insert_data
             @xxx [05-31-2022 12:41:14]: documentation for insert_data
         '''
-        if self.data['insert_data'] is None:
+        if self.init_gen_insert is False:
             self.gen_insert_data()
         return self.data['insert_data']
 
