@@ -345,6 +345,34 @@ class TableManager:
         if success:
             return self.reset_default_table()
 
+    @property
+    def default_data(self)->list:
+        '''
+            Get this tables default data list.
+
+            ----------
+
+
+            Return {list}
+            ----------------------
+            A list of dictionaries.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 06-09-2022 14:58:12
+            `memberOf`: TableManager
+            `version`: 1.0
+            `method_name`: default_data
+            * @xxx [06-09-2022 14:59:29]: documentation for default_data
+        '''
+
+
+        return self.default_data_manager.insert_data
+        # return self.data['default_insert_data']
+
+
+
     def gen_test_reset(self):
         '''
             Generate the test data insert SQL and sync the new data to the database.
